@@ -15,11 +15,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-# XXX disable GC
-#import gc; gc.disable()
-
 import sys, os, os.path, weakref,cPickle as  pickle
 
+if os.path.exists(os.path.join(__path__[0], "build")):
+  # We are using a source directory.
+  # We need to get the binary library in "./build/xxx"
+  import distutils.util
+  __path__.append(os.path.join(__path__[0], "build", "lib.%s-%s" % (distutils.util.get_platform(), sys.version[0:3]), "soya"))
+
 from soya._soya import *
 from soya._soya import _CObj
 
@@ -269,7 +272,8 @@ Attributes are:
   coordinates are out of the range 0 - 1.0.
 
 - additive_blending: set it to true for additive blending. For semi-transparent surfaces
-  (=alpha blended) only. Usefull for special effect (Ray, Sprite,...)."""
+  (=alpha blended) only. Usefull for special effect (Ray, Sprite,...).
+"""
 
   DIRNAME = "materials"
   _alls = weakref.WeakValueDictionary()
@@ -325,16 +329,44 @@ class CellShadingShape(Shape, _soya._CellShadingShape):
 
 
 class Point(_soya._Point):
-  pass
+  """A Point is just a 3D position. It is used for math computation, but it DOESN'T display
+anything."""
 
 class Vector(_soya._Vector):
-  pass
+  """A Vector is a 3D vector (and not a kind of list or sequence ;-). Vectors are
+useful for 3D math computation. 
+
+Most of the math operators, such as +, -, *, /, abs,... work on Vectors and do
+what they are intended to do ;-)"""
 
 class Vertex(_soya._Vertex):
-  pass
+  """Vertex
 
+A Vertex is a subclass of Point, which is used for building Faces.
+A Vertex doesn't display anything ; you MUST put it inside a Face.
+
+Attributes are (see also Point for inherited attributes):
+
+# - diffuse: the vertex diffuse color (also aliased to 'color' for compatibility)
+# - emissive: the vertex emissive color (lighting-independant color)
+# - tex_x, tex_y: the text
+ure coordinates (sometime called U and V).
+"""
+  
   
 class Volume(_soya._Volume):
+  """Volume
+
+A Volume is a Soya 3D object that display a Shape. The Volume contains data about the
+position, the orientation and the scaling, and the Shape contains the geometric data.
+
+This separation allows to use several time the same Shape at different position, without
+dupplicating the geometric data.
+
+Attributes are (see also CoordSyst for inherited attributes):
+
+ - shape : the Shape (a Shape object, defaults to None).
+"""
   pass
 
 def do_cmd(cmd):
@@ -342,6 +374,26 @@ def do_cmd(cmd):
   os.system(cmd)
   
 class World(SavedInAPath, _soya._World, Volume):
+  """World
+
+A World is a Soya 3D object that can contain other Soya 3D objects, including other Worlds.
+Worlds are used to group 3D objects ; when a World is moved, all the objects it contains
+are moved too, since they are part of the World.
+Mostly for historical reasons, World is a subclass of Volume, and thus can display a Shape.
+
+Worlds can be saved in the "worlds" directory ; see SavedInAPath.
+
+Attributes are (see also Volume, CoordSyst and SavedInAPath for inherited attributes):
+
+ - children : the list of 3D object contained in the World (default to an empty list).
+   use World.add(coordsyst) and World.remove(coordsyst) for additions and removals.
+ - atmosphere : the atmosphere specifies atmospheric properties of the World (see
+   Atmosphere). Default is None.
+ - shapifier : the shapifier specifies how the World is compiled into Shape.
+   Default is None, which result in the use of the default Shapifier, which is
+   SimpleShapifier().
+"""
+
   DIRNAME = "worlds"
   _alls = weakref.WeakValueDictionary()
   
@@ -349,23 +401,15 @@ class World(SavedInAPath, _soya._World, Volume):
     need_export, source_file, file = klass._check_export(filename + ".data", filename, ("blender", filename.split("@")[0] + ".blend"), ("obj", filename + ".obj"), ("obj", filename + ".mtl"), ("3ds", filename + ".3ds"))
     if need_export:
       if   need_export == "blender":
-        animation, time = "", 0
         extra = ""
         
         if "@" in filename:
-          args = filename[filename.index("@") + 1:].split(",")
-          if args[0]: animation, time = args[0].split(":")
-          del args[0]
-          for arg in args:
-            print arg, args
-            extra += "MATERIAL_%s=%s" % tuple(arg.split(":"))
+          extra += "CONFIG_TEXT=%s" % filename[filename.index("@") + 1:]
             
-        do_cmd("blender %s -P %s --blender2soya FILENAME=%s ANIMATION=%s ANIMATION_TIME=%s %s" % (
+        do_cmd("blender %s -P %s --blender2soya FILENAME=%s %s" % (
           source_file,
           os.path.join(os.path.dirname(__file__), "blender2soya.py"),
           filename,
-          animation,
-          time,
           extra,
           ))
         
@@ -388,13 +432,85 @@ class World(SavedInAPath, _soya._World, Volume):
   
 
 class Light(_soya._Light):
-  pass
+  """Light
+
+A Light is a 3D object that enlights the other objects.
+
+Attributes are (see also CoordSyst for inherited attributes):
+
+ - directional : True for a directional light (e.g. like the sun), instead of a
+   positional light. The position of a directional light doesn't matter, and only
+   the constant component of the attenuation is used. Default is false.
+ - constant, linear and quadratic : the 3 components of the light attenuation. Constant
+   reduces the light independently of the distance, linear increase with the distance,
+   and quadratic increase the squared distance. Default is 1.0, 0.0 and 0.0.
+ - cast_shadow : True if the light cast shadows on Shapes that have shadows enabled.
+   Default is true.
+ - shadow_color : the color of the shadow . Default is a semi-transparent black
+   (0.0, 0.0, 0.0, 0.5).
+ - top_level : XXX ???
+ - static : True if the light can be used for static lighting when compiling a World into
+   a Shape. Default is true.
+ - ambient : the light's ambient color, which is not affected by the light's orientation
+   or attenuation. Default is black (no ambient).
+ - diffuse : the light's color. Default is white.
+ - specular : the light's specular color. Default is white.
+"""
 
 class Camera(_soya._Camera):
-  pass
+  """Camera
+
+The Camera specifies from where the scene is viewed.
+
+Attributes are (see also CoordSyst and Widget for inherited attributes):
+
+ - front, back : objects whose distance from the camera is not between front and back
+   are clipped. Front defaults to 0.1 and back to 100.0.
+   If the back / front ratio is too big, you loose precision in the depth buffer.
+ - fov : the field of vision (or FOV), in degrees. Default is 60.0.
+ - to_render : the world that is rendered by the camera. Default is None, which means
+   the root scene (as returned by get_root()).
+ - left, top, width, height : the viewport rectangle, in pixel. Use it if you want to
+   render only on a part of the screen. It defaults to the whole screen.
+ - ortho : True for orthogonal rendering, instead of perspective. Default is false.
+ - partial : XXX ???.
+"""
 
 class Face(_soya._Face):
-  pass
+  """Face
+
+A Face displays a polygon composed of several Vertices (see the Vertex class).
+Notice that Face are SLOW ; Faces are normally used for building model but not for
+rendering them. To get a fast rendering, you should put several Faces in a World, and
+then compile the World into a Shape (see the modeling-X.py tutorial series).
+
+According to the number of Vertices, the result differs:
+- 1 Vertex => Plot
+- 2        => Line
+- 3        => Triangle
+- 4        => Quad
+
+All the vertices are expected to be coplannar.
+
+Interesting properties are:
+
+- vertices: the list of Vertices
+- material: the material used to draw the face's surface
+- double_sided: true if you want to see both sides of the Face. Default is false.
+- solid: true to enable the use of this Face for raypicking. Default is true.
+- lit: true to enable lighting on the Face. Default is true.
+
+The following options are used when compiling the Face into a Shape,
+but does not affect the rendering of the Face itself:
+
+- static_lit: true to enable static lighting (faster). If true, when compiling the Face
+  into a Shape, all Lights available will be applied as static lighting. Default is true.
+- smooth_lit: true to compute per-vertex normal vectors, instead of per-face normal vector.
+  This makes the Shape looking smooth (see tutorial modeling-smoothlit-1.py).
+  Notice that Soya automatically disable smooth_lit between 2 faces that makes a sharp
+  angle (see Shapifier.max_face_angle attribute).
+  Default is false.
+"""
 
 class Atmosphere(_soya._Atmosphere):
   pass
