@@ -37,8 +37,9 @@ void init_advanced_opengl(void);
 #define GLAPIENTRY
 #endif
 
-#ifndef __WIN32__
 
+// You may need to uncomment this if you use an old MacOS X
+/*
 typedef void (GLAPIENTRY *_GLUfuncptr)();
+*/
 
-#endif
