@@ -133,18 +133,14 @@ MESSAGES = ""
 # The script should be quite re-useable for writing another Blender animation exporter.
 # Most of the hell of it is to deal with Blender's head-tail-roll bone's definition.
 
-print 
-
 import sys, os, os.path, struct, math, string
 
-psyco=0
-
-if psyco:
+try:
   import psyco
-  psyco.log()
   psyco.full()
-  psyco.profile(0.9)
-
+except:
+  print "* Blender2Cal3D * (Psyco not found)"
+  
 import Blender
 from Blender import Registry
 from Blender.Window import DrawProgressBar
@@ -241,7 +237,7 @@ log.addHandler(handler)
 # set this to minimum output level. eg. logging.DEBUG, logging.WARNING, logging.ERROR
 # logging.CRITICAL. logging.INFO will make little difference as these always get 
 # output'd
-log.setLevel(logging.DEBUG)
+log.setLevel(logging.WARNING)
 
 log.info("Starting...")
 
@@ -731,7 +727,7 @@ class Vertex:
     s += "".join(map(Influence.to_cal3d, self.influences))
     if not self.weight is None: s += struct.pack("f", len(self.weight))
     return s
-
+  
   def to_cal3d_xml(self):
     if self.collapse_to:
       collapse_id = self.collapse_to.id
@@ -839,7 +835,8 @@ class Bone:
     self.rot = rot
     self.children = []
     
-    self.matrix = matrix_translate(quaternion2matrix(rot), loc)
+    self.matrix = self.local_matrix = matrix_translate(quaternion2matrix(rot), loc)
+    
     if parent:
       self.matrix = matrix_multiply(parent.matrix, self.matrix)
       parent.children.append(self)
@@ -942,7 +939,7 @@ class KeyFrame:
   def to_cal3d(self):
     # We need to negate quaternion W value, but why ?
     return struct.pack("ffffffff", self.time, self.loc[0], self.loc[1], self.loc[2], self.rot[0], self.rot[1], self.rot[2], -self.rot[3])
-
+  
   def to_cal3d_xml(self):
     s = "    <KEYFRAME TIME=\"%f\">\n" % self.time
     s += "      <TRANSLATION>%f %f %f</TRANSLATION>\n" % \
@@ -952,7 +949,7 @@ class KeyFrame:
          (self.rot[0], self.rot[1], self.rot[2], -self.rot[3])
     s += "    </KEYFRAME>\n"
     return s                                                      
-
+  
 def export(filename):
   global MESSAGES
   
@@ -1107,7 +1104,7 @@ def export(filename):
                 if face.smooth:
                   normal = vector_normalize(vector_by_matrix(face.v[i].no, matrix))
                 vertex  = vertices[face.v[i].index] = Vertex(submesh, coord, normal)
-
+                
                 influences = data.getVertexInfluences(face.v[i].index)
                 # should this really be a warning? (well currently enabled,
                 # because blender has some bugs where it doesn't return
@@ -1251,11 +1248,12 @@ def export(filename):
         if quat==[0,0,0,0]:
           log.critical('You are using just Loc keys. You must use LocRot keys instead.')
           continue
-         
-        transt = vector_by_matrix(trans, bone.matrix)
+        
+        transt = vector_by_matrix(trans, bone.local_matrix)
+          
         loc = vector_add(bone.loc, transt)
         rot = quaternion_multiply(quat, bone.rot)
-
+        
         try:
           rot = quaternion_normalize(rot)
         except:
@@ -1275,6 +1273,10 @@ def export(filename):
     filename = os.path.splitext(filename)[0]
   BASENAME = os.path.basename(filename)         
   DIRNAME  = os.path.dirname(filename)
+
+  try: os.makedirs(DIRNAME)
+  except: pass
+  
   if PREFIX_FILE_WITH_MODEL_NAME: PREFIX = BASENAME + "_"
   else:                           PREFIX = ""
   if XML: FORMAT_PREFIX = "x"; encode = lambda x: x.to_cal3d_xml()
@@ -1321,6 +1323,12 @@ def export(filename):
     print >> cfg, "material=%s" % filename
   print >> cfg
   
+  try:
+    glob_params = Blender.Text.get("soya_params").asLines()
+    for glob_param in glob_params:
+      print >> cfg, glob_param
+  except: pass
+      
   log.info("Saved to '%s.cfg'" % BASENAME)
   log.info("Done.")
   
