@@ -13,8 +13,19 @@ class Body(_ode._Body, soya.World):
 
 _ode.Body = Body
 
-class Land(_ode._Land, soya.Land):
+class Land(_ode._Land):
     pass
 
 _ode.Land = Land
 
+class GeomShape(_ode._GeomShape):
+    pass
+
+_ode.GeomShape = GeomShape
+
+class GeomLand(_ode._GeomLand):
+    pass
+
+_ode.GeomLand = GeomLand
+
+
