@@ -212,10 +212,10 @@ class Label(Widget):
     self._changed = -2
     Widget.resize(self, parent_left, parent_top, parent_width, parent_height)
     
-  def __init__(self, master = None, text = "", align = 0, color = (1.0, 1.0, 1.0, 1.0), font = default_font, resize_style = None):
+  def __init__(self, master = None, text = "", align = 0, color = (1.0, 1.0, 1.0, 1.0), font = None, resize_style = None):
     self._text    = text
     self._color   = color
-    self._font    = font
+    self._font    = font or default_font
     self._align   = align # align: 0 left, 1 center
     self._changed = -2
     self._id      = glGenList()
@@ -225,22 +225,27 @@ class Label(Widget):
     glDeleteList(self._id)
     
   def build_display_list(self):
+    """Label.build_display_list()
+
+Really renders the text.
+
+If you override this method, DO NOT SET self.text or self._set here !!!
+It might call glyph tessellation that would be included in the display list !"""
     glColor4f(*self._color)
     self._font.draw_area(self._text, self.left, self.top, 0.0, self.width, self.height, self._align)
     
   def render(self):
+    soya.DEFAULT_MATERIAL.activate()
     if self._changed != self._font._pixels_height:
       self._font.create_glyphs(self._text)
       
-      soya.DEFAULT_MATERIAL.activate()
       glNewList(self._id, GL_COMPILE_AND_EXECUTE)
       self.build_display_list()
       glEndList()
       self._changed = self._font._pixels_height
     else:
-      soya.DEFAULT_MATERIAL.activate()
       glCallList(self._id)
-        
+      
 
 
 # class FPSLabel(Widget):
@@ -271,10 +276,11 @@ It works ONLY with soya.idler !!!"""
     self.fps = -1.0
     
   def resize(self, parent_left, parent_top, parent_width, parent_height):
-    self.left   = parent_left + parent_width  - 120
-    self.top    = parent_top  + parent_height - 37
-    self.width  = 120
-    self.height = 37
+    self.width, self.height = self.font.get_print_size("30.0 FPS")
+    self.width  += 10
+    self.height +=  5
+    self.left   = parent_left + parent_width  - self.width
+    self.top    = parent_top  + parent_height - self.height
     self._changed = -2
     
   def widget_begin_round(self):
@@ -289,7 +295,7 @@ It works ONLY with soya.idler !!!"""
         
         
 class Image(Widget):
-  def __init__(self, master = None, material = None, color = soya.WHITE):
+  def __init__(self, master = None, material = None, color = soya.WHITE, resize_style = None):
     # mode 0 : normal
     # mode 1 : texcoords follow the height and width of the widget
     self.tex_mode   = 0
@@ -300,7 +306,7 @@ class Image(Widget):
     self.tex_right  = 1.0
     self.color      = color
     self.rotz        = 0.0
-    Widget.__init__(self, master)
+    Widget.__init__(self, master, resize_style)
     
   def render(self):
     self.material.activate()
@@ -341,10 +347,10 @@ class Image(Widget):
 
 class BannerElement:
   
-  def __init__(self, text = "", color = (1.0, 1.0, 1.0, 1.0), font = default_font):
+  def __init__(self, text = "", color = (1.0, 1.0, 1.0, 1.0), font = None):
     self.text = text
     self.color = color
-    self.font = font
+    self.font = font or default_font
 
   def compute_size(self, width = None):
     if width == None:
@@ -618,16 +624,16 @@ class ChoiceInput:
   def key_down(self, key_id, mods):
     if (key_id == soya.sdlconst.K_DELETE or key_id == soya.sdlconst.K_BACKSPACE or key_id == soya.sdlconst.K_CLEAR):
       self.value = self.value[:-1]
-    elif (key_id == soya.sdlconst.K_KP0 or key_id == soya.sdlconst.K_0): self.value += '0'
-    elif (key_id == soya.sdlconst.K_KP1 or key_id == soya.sdlconst.K_1): self.value += '1'
-    elif (key_id == soya.sdlconst.K_KP2 or key_id == soya.sdlconst.K_2): self.value += '2'
-    elif (key_id == soya.sdlconst.K_KP3 or key_id == soya.sdlconst.K_3): self.value += '3'
-    elif (key_id == soya.sdlconst.K_KP4 or key_id == soya.sdlconst.K_4): self.value += '4'
-    elif (key_id == soya.sdlconst.K_KP5 or key_id == soya.sdlconst.K_5): self.value += '5'
-    elif (key_id == soya.sdlconst.K_KP6 or key_id == soya.sdlconst.K_6): self.value += '6'
-    elif (key_id == soya.sdlconst.K_KP7 or key_id == soya.sdlconst.K_7): self.value += '7'
-    elif (key_id == soya.sdlconst.K_KP8 or key_id == soya.sdlconst.K_8): self.value += '8'
-    elif (key_id == soya.sdlconst.K_KP9 or key_id == soya.sdlconst.K_9): self.value += '9'
+    elif (key_id == soya.sdlconst.K_KP0) or (key_id == soya.sdlconst.K_0): self.value += '0'
+    elif (key_id == soya.sdlconst.K_KP1) or (key_id == soya.sdlconst.K_1): self.value += '1'
+    elif (key_id == soya.sdlconst.K_KP2) or (key_id == soya.sdlconst.K_2): self.value += '2'
+    elif (key_id == soya.sdlconst.K_KP3) or (key_id == soya.sdlconst.K_3): self.value += '3'
+    elif (key_id == soya.sdlconst.K_KP4) or (key_id == soya.sdlconst.K_4): self.value += '4'
+    elif (key_id == soya.sdlconst.K_KP5) or (key_id == soya.sdlconst.K_5): self.value += '5'
+    elif (key_id == soya.sdlconst.K_KP6) or (key_id == soya.sdlconst.K_6): self.value += '6'
+    elif (key_id == soya.sdlconst.K_KP7) or (key_id == soya.sdlconst.K_7): self.value += '7'
+    elif (key_id == soya.sdlconst.K_KP8) or (key_id == soya.sdlconst.K_8): self.value += '8'
+    elif (key_id == soya.sdlconst.K_KP9) or (key_id == soya.sdlconst.K_9): self.value += '9'
     elif (key_id == soya.sdlconst.K_KP_PERIOD or key_id == soya.sdlconst.K_PERIOD): self.value += '.'
     else:
       if mods & (soya.sdlconst.MOD_SHIFT | soya.sdlconst.MOD_CAPS):
@@ -643,14 +649,14 @@ class ChoiceInput:
 
 class ChoiceList(Widget):
 
-  def __init__(self, master = None, choices = [], font = default_font, color = (1.0, 0.5, 0.5, 1.0), highlight = (1.0, 1.0, 0.0, 1.0), cancel = None,align=1):
+  def __init__(self, master = None, choices = [], font = None, color = (1.0, 0.5, 0.5, 1.0), highlight = (1.0, 1.0, 0.0, 1.0), cancel = None,align=1):
     self.x_percent = 0.0
     self.y_percent = 0.0
     self.w_percent = 1.0
     self.h_percent = 1.0
     Widget.__init__(self, master)
     self.choices = choices
-    self.font = font
+    self.font = font or default_font
     self.color = color
     self.highlight = highlight
     self.selected = 0
@@ -732,7 +738,7 @@ class ChoiceList(Widget):
 
 class Selector(Widget):
 
-  def __init__(self, master = None, choices = [], title = None, font = default_font, color = (1.0, 0.5, 0.5, 1.0), highlight = (1.0, 1.0, 0.0, 1.0), arrows = None):
+  def __init__(self, master = None, choices = [], title = None, font = None, color = (1.0, 0.5, 0.5, 1.0), highlight = (1.0, 1.0, 0.0, 1.0), arrows = None):
     self.x_percent = 0.0
     self.y_percent = 0.0
     self.w_percent = 1.0
@@ -741,7 +747,7 @@ class Selector(Widget):
     self.choices = choices
     self.title = title
     self.nb_displayed = 5
-    self.font = font
+    self.font = font or default_font
     self.arrows = arrows
     Widget.__init__(self, master)
     self.selected  = 0
